@@ -100,9 +100,9 @@ void LockScreen::setHildonFlags()
     Atom winDNDAtom = XInternAtom(QX11Info::display(), "_HILDON_DO_NOT_DISTURB", false);
     XChangeProperty(QX11Info::display(), m_View->winId(), winDNDAtom, XA_INTEGER, 32, PropModeReplace, (uchar*) &enable, 1);
 
-    /*enable = 1;
+    enable = 1;
     Atom winNTAtom = XInternAtom(QX11Info::display(), "_HILDON_WM_ACTION_NO_TRANSITIONS", false);
-    XChangeProperty(QX11Info::display(), m_View->winId(), winNTAtom, XA_INTEGER, 32, PropModeReplace, (uchar*) &enable, 1);*/
+    XChangeProperty(QX11Info::display(), m_View->winId(), winNTAtom, XA_INTEGER, 32, PropModeReplace, (uchar*) &enable, 1);
 
 #endif
 }
