@@ -72,8 +72,7 @@ void LsBattery::applySettings()
             m_Images.append(i);
     }
 
-    m_PercFont = QFont();
-    m_PercFont.setPointSize(getSetting("PercentageFontSize", 15).toInt());
+    m_PercFont = getFontSetting("PercentageFont", QFont("", 15, QFont::Normal, false));
 }
 
 #ifdef Q_WS_MAEMO_5
