@@ -70,8 +70,7 @@ void LsNotification::applySettings()
     m_Icon = QPixmap(getSetting("Icon", defName).toString());
 
     m_Color = getColorSetting("Color", QColor(255,255,255));
-    m_Font = QFont();
-    m_Font.setPointSize(getSetting("FontSize", 12).toInt());
+    m_Font = getFontSetting("Font", QFont("", 14, QFont::Normal, false));
 }
 
 void LsNotification::stopUpdate()
