@@ -119,6 +119,39 @@ Qt::AlignmentFlag LsWidget::getAlignmentSetting(QString name, Qt::AlignmentFlag
     return defaultValue;
 }
 
+QFont LsWidget::getFontSetting(QString name, QFont defaultValue)
+{
+    QString fSettings = getSetting(name, "").toString();
+    if (!fSettings.isEmpty()){
+        QStringList elem = fSettings.split(';');
+        if (elem.count() == 4){
+            QString family = elem.at(0);
+            if (family.isEmpty())
+                family = QApplication::font().family();
+            int pointSize = elem.at(1).toInt();
+            if (pointSize <= 0)
+                pointSize = 12;
+
+            int weight = QFont::Normal;
+            QString sWeight = elem.at(2).toLower();
+            if (sWeight == "light")
+                weight = QFont::Light;
+            else if (sWeight == "normal")
+                weight = QFont::Normal;
+            else if (sWeight == "demibold")
+                weight = QFont::DemiBold;
+            else if (sWeight == "bold")
+                weight = QFont::Bold;
+            else if (sWeight == "black")
+                weight = QFont::Black;
+            bool italic = elem.at(3).toInt() == 1;
+
+            return QFont(family, pointSize, weight, italic);
+        }
+    }
+    return defaultValue;
+}
+
 void LsWidget::setName(QString name)
 {
     m_Name = name;
